@@ -36,6 +36,13 @@ def test_option_list():
 # 
 # """
 
+@attr(syntax=1)
+def test_new_lines_to_spaces():
+    # http://code.google.com/p/wikir/issues/detail?id=4
+    match(
+        publish_string("foo *bar*\nquux"),
+        "foo *bar* quux\n\n")
+
 @attr(syntax=1)
 def test_headers():
     match(publish_string(dedent("""
